@@ -775,6 +775,10 @@ class PMA_Table
 
         // Copy the data unless this is a VIEW
         if (($what == 'data' || $what == 'dataonly') && ! PMA_Table::_isView($target_db,$target_table)) {
+            $sql_set_mode = "SET SQL_MODE='NO_AUTO_VALUE_ON_ZERO'";
+            PMA_DBI_query($sql_set_mode);
+            $GLOBALS['sql_query'] .= "\n\n" . $sql_set_mode . ';';
+
             $sql_insert_data =
                 'INSERT INTO ' . $target . ' SELECT * FROM ' . $source;
             PMA_DBI_query($sql_insert_data);
@@ -1008,6 +1012,7 @@ class PMA_Table
      * @param   string  new database name
      * @param   boolean is this for a VIEW rename?
      * @return  boolean success
+     * @todo    remove the $is_view parameter (also in callers)
      */
     function rename($new_name, $new_db = null, $is_view = false)
     {
@@ -1032,17 +1037,32 @@ class PMA_Table
             return false;
         }
 
-        if (! $is_view) {
-            $GLOBALS['sql_query'] = '
-                RENAME TABLE ' . $this->getFullName(true) . '
-                      TO ' . $new_table->getFullName(true) . ';';
-        } else {
-            $GLOBALS['sql_query'] = '
-                ALTER TABLE ' . $this->getFullName(true) . '
-                RENAME ' . $new_table->getFullName(true) . ';';
+        // If the table is moved to a different database drop its triggers first
+        $triggers = PMA_DBI_get_triggers($this->getDbName(), $this->getName(), '');
+        $handle_triggers = $this->getDbName() != $new_db && $triggers;
+        if ($handle_triggers) {
+            foreach ($triggers as $trigger) {
+                $sql = 'DROP TRIGGER IF EXISTS ' . PMA_backquote($this->getDbName()) . '.'
+                    . PMA_backquote($trigger['name']) . ';';
+                PMA_DBI_query($sql);
+            }
         }
+
+        /*
+         * tested also for a view, in MySQL 5.0.92, 5.1.55 and 5.5.13
+         */
+        $GLOBALS['sql_query'] = '
+            RENAME TABLE ' . $this->getFullName(true) . '
+                  TO ' . $new_table->getFullName(true) . ';';
         // I don't think a specific error message for views is necessary
         if (! PMA_DBI_query($GLOBALS['sql_query'])) {
+            // Restore triggers in the old database
+            if ($handle_triggers) {
+                PMA_DBI_select_db($this->getDbName());
+                foreach ($triggers as $trigger) {
+                    PMA_DBI_query($trigger['create']);
+                }
+            }
             $this->errors[] = sprintf(__('Error renaming table %1$s to %2$s'), $this->getFullName(), $new_table->getFullName());
             return false;
         }
