@@ -2,9 +2,14 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * @package phpMyAdmin-Transformation
- * @version $Id: application_octetstream__download.inc.php 11973 2008-11-24 09:30:37Z nijel $
  */
 
+function PMA_transformation_application_octetstream__download_info() {
+    return array(
+        'info' =>  __('Displays a link to download the binary data of the column. You can use the first option to specify the filename, or use the second option as the name of a column which contains the filename. If you use the second option, you need to set the first option to the empty string.'),
+        );
+}
+
 /**
  *
  */
